@@ -1096,6 +1096,7 @@ mod tests {
                 archived: false,
                 auto_archive_duration: AutoArchiveDuration::Day,
                 archive_timestamp: timestamp,
+                create_timestamp: Some(timestamp),
                 invitable: None,
                 locked: false,
             },
@@ -1125,6 +1126,7 @@ mod tests {
                     "archive_timestamp": formatted,
                     "archived": false,
                     "auto_archive_duration": AutoArchiveDuration::Day,
+                    "create_timestamp": formatted,
                     "locked": false
                 }
             }))
@@ -1160,6 +1162,7 @@ mod tests {
                 archived: false,
                 auto_archive_duration: AutoArchiveDuration::Day,
                 archive_timestamp: timestamp,
+                create_timestamp: Some(timestamp),
                 invitable: None,
                 locked: false,
             },
@@ -1189,6 +1192,7 @@ mod tests {
                     "archive_timestamp": timestamp,
                     "archived": false,
                     "auto_archive_duration": AutoArchiveDuration::Day,
+                    "create_timestamp": timestamp,
                     "locked": false
                 }
             }))
@@ -1231,6 +1235,7 @@ mod tests {
                 archived: false,
                 auto_archive_duration: AutoArchiveDuration::Day,
                 archive_timestamp: timestamp,
+                create_timestamp: Some(timestamp),
                 invitable: None,
                 locked: false,
             },
@@ -1261,6 +1266,7 @@ mod tests {
                     "archive_timestamp": formatted,
                     "archived": false,
                     "auto_archive_duration": AutoArchiveDuration::Day,
+                    "create_timestamp": formatted,
                     "locked": false
                 },
                 "permission_overwrites": [
