@@ -1,8 +1,8 @@
 use crate::{
     datetime::Timestamp,
-    gateway::presence::Presence,
-    guild::Member,
-    id::{ChannelId, UserId},
+    gateway::presence::{Presence, PresenceIntermediary},
+    guild::{member::MemberIntermediary, Member},
+    id::{ChannelId, GuildId, UserId},
 };
 use serde::{Deserialize, Serialize};
 
@@ -21,6 +21,39 @@ pub struct ThreadMember {
     pub user_id: Option<UserId>,
 }
 
+/// Version of [`ThreadMember`], but without a guild ID in the
+/// [`Self::member`] field.
+#[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq)]
+pub struct ThreadMemberIntermediary {
+    // Values currently unknown and undocumented.
+    pub flags: u64,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub id: Option<ChannelId>,
+    pub join_timestamp: Timestamp,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub member: Option<MemberIntermediary>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub presence: Option<PresenceIntermediary>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub user_id: Option<UserId>,
+}
+
+impl ThreadMemberIntermediary {
+    /// Inject a guild ID into a thread member intermediary
+    pub fn into_thread_member(self, guild_id: GuildId) -> ThreadMember {
+        let member = self.member.map(|m| m.into_member(guild_id));
+        let presence = self.presence.map(|p| p.into_presence(guild_id));
+        ThreadMember {
+            flags: self.flags,
+            id: self.id,
+            join_timestamp: self.join_timestamp,
+            member,
+            presence,
+            user_id: self.user_id,
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::{ChannelId, ThreadMember, UserId};
