@@ -83,6 +83,7 @@ mod tests {
                 archived: true,
                 auto_archive_duration: AutoArchiveDuration::Hour,
                 archive_timestamp: timestamp,
+                create_timestamp: Some(timestamp),
                 invitable: Some(true),
                 locked: true,
             },
@@ -156,7 +157,7 @@ mod tests {
                 Token::Str("thread_metadata"),
                 Token::Struct {
                     name: "ThreadMetadata",
-                    len: 5,
+                    len: 6,
                 },
                 Token::Str("archived"),
                 Token::Bool(true),
@@ -164,6 +165,9 @@ mod tests {
                 Token::U16(60),
                 Token::Str("archive_timestamp"),
                 Token::Str(DATETIME),
+                Token::Str("create_timestamp"),
+                Token::Some,
+                Token::Str(DATETIME),
                 Token::Str("invitable"),
                 Token::Some,
                 Token::Bool(true),
