@@ -74,6 +74,7 @@ mod tests {
                 archived: true,
                 auto_archive_duration: AutoArchiveDuration::Hour,
                 archive_timestamp: timestamp,
+                create_timestamp: Some(timestamp),
                 invitable: None,
                 locked: true,
             },
@@ -141,7 +142,7 @@ mod tests {
                 Token::Str("thread_metadata"),
                 Token::Struct {
                     name: "ThreadMetadata",
-                    len: 4,
+                    len: 5,
                 },
                 Token::Str("archived"),
                 Token::Bool(true),
@@ -149,6 +150,9 @@ mod tests {
                 Token::U16(60),
                 Token::Str("archive_timestamp"),
                 Token::Str(DATETIME),
+                Token::Str("create_timestamp"),
+                Token::Some,
+                Token::Str(DATETIME),
                 Token::Str("locked"),
                 Token::Bool(true),
                 Token::StructEnd,
