@@ -607,6 +607,7 @@ mod tests {
     "nsfw_level": 1,
     "owner_id": "13311",
     "preferred_locale": "en-US",
+    "premium_progress_bar_enabled": true,
     "premium_subscription_count": 4,
     "premium_tier": 1,
     "region": "eu-central",
@@ -677,6 +678,7 @@ mod tests {
     "nsfw_level": 0,
     "owner_id": "46",
     "preferred_locale": "en-US",
+    "premium_progress_bar_enabled": false,
     "premium_subscription_count": null,
     "premium_tier": 0,
     "region": "us-central",
